@@ -483,7 +483,7 @@ void setosize(xcWidget w, objinstptr dataptr)
    if (tmpres < 0)
       tmpres = -tmpres;
 
-   if (res == 0 || tmpres <= 0) {
+   if (res == 0 || tmpres == 0) {
       Wprintf("Illegal value");
       return;
    }
