@@ -13,6 +13,7 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
+#include <termios.h>
 #ifndef XC_WIN32
 #include <unistd.h>
 #endif
@@ -590,7 +591,7 @@ void loadbackground()
 void send_to_gs(char *text)
 {
    write(fgs[1], text, strlen(text));
-   fflush(fgs[1]);
+   tcflush(fgs[1], TCOFLUSH);
 #ifdef GS_DEBUG
    fprintf(stdout, "writing: %s", text);
 #endif
